# Generated by roxygen2: do not edit by hand

S3method(print,ctx_credentials)
export(check_existence_by_dtxsid)
export(check_existence_by_dtxsid_batch)
export(chemical_contains)
export(chemical_contains_batch)
export(chemical_equal)
export(chemical_equal_batch)
export(chemical_starts_with)
export(chemical_starts_with_batch)
export(ctxR_hide_api_key)
export(ctxR_show_api_key)
export(ctx_key)
export(get_aggregate_records_by_dtxsid)
export(get_aggregate_records_by_dtxsid_batch)
export(get_aggregate_records_by_medium)
export(get_aggregate_records_by_medium_batch)
export(get_all_assays)
export(get_all_list_types)
export(get_all_public_chemical_lists)
export(get_annotation_by_aeid)
export(get_annotation_by_aeid_batch)
export(get_bioactivity_details)
export(get_bioactivity_details_batch)
export(get_bioactivity_endpoint_status)
export(get_bioactivity_summary)
export(get_bioactivity_summary_batch)
export(get_biomonitoring_data)
export(get_biomonitoring_data_batch)
export(get_cancer_hazard)
export(get_cancer_hazard_batch)
export(get_chem_info)
export(get_chem_info_batch)
export(get_chem_props_exp)
export(get_chem_props_exp_batch)
export(get_chem_props_pred)
export(get_chem_props_pred_batch)
export(get_chem_props_summary)
export(get_chemical_by_property_range)
export(get_chemical_by_property_range_batch)
export(get_chemical_details)
export(get_chemical_details_batch)
export(get_chemical_endpoint_status)
export(get_chemical_image)
export(get_chemical_image_batch)
export(get_chemical_lists_by_type)
export(get_chemical_lists_by_type_batch)
export(get_chemical_mol)
export(get_chemical_mol_batch)
export(get_chemical_mrv)
export(get_chemical_mrv_batch)
export(get_chemical_synonym)
export(get_chemical_synonym_batch)
export(get_chemical_weight_fraction)
export(get_chemical_weight_fraction_batch)
export(get_chemicals_in_list)
export(get_chemicals_in_list_batch)
export(get_chemicals_in_list_contain)
export(get_chemicals_in_list_contain_batch)
export(get_chemicals_in_list_exact)
export(get_chemicals_in_list_exact_batch)
export(get_chemicals_in_list_start)
export(get_chemicals_in_list_start_batch)
export(get_demographic_exposure_prediction)
export(get_demographic_exposure_prediction_batch)
export(get_ecotox_hazard_by_dtxsid)
export(get_ecotox_hazard_by_dtxsid_batch)
export(get_exposure_endpoint_status)
export(get_exposure_functional_use)
export(get_exposure_functional_use_batch)
export(get_exposure_functional_use_category)
export(get_exposure_functional_use_probability)
export(get_exposure_functional_use_probability_batch)
export(get_exposure_list_presence_tags)
export(get_exposure_list_presence_tags_by_dtxsid)
export(get_exposure_list_presence_tags_by_dtxsid_batch)
export(get_exposure_product_data)
export(get_exposure_product_data_batch)
export(get_exposure_product_data_puc)
export(get_fate_by_dtxsid)
export(get_fate_by_dtxsid_batch)
export(get_general_exposure_prediction)
export(get_general_exposure_prediction_batch)
export(get_general_use_keywords)
export(get_general_use_keywords_batch)
export(get_genetox_details)
export(get_genetox_details_batch)
export(get_genetox_summary)
export(get_genetox_summary_batch)
export(get_hazard_by_dtxsid)
export(get_hazard_by_dtxsid_batch)
export(get_hazard_endpoint_status)
export(get_httk_data)
export(get_httk_data_batch)
export(get_human_hazard_by_dtxsid)
export(get_human_hazard_by_dtxsid_batch)
export(get_inchi)
export(get_inchikey)
export(get_lists_containing_chemical)
export(get_lists_containing_chemical_batch)
export(get_medium_categories)
export(get_msready_by_dtxcid)
export(get_msready_by_dtxcid_batch)
export(get_msready_by_formula)
export(get_msready_by_formula_batch)
export(get_msready_by_mass)
export(get_msready_by_mass_batch)
export(get_msready_by_mass_with_error_batch)
export(get_product_use_categories_batch)
export(get_product_use_category)
export(get_production_volume)
export(get_production_volume_batch)
export(get_public_chemical_list_by_name)
export(get_public_chemical_list_by_name_batch)
export(get_reported_functional_use)
export(get_reported_functional_use_batch)
export(get_single_sample_records_by_dtxsid)
export(get_single_sample_records_by_dtxsid_batch)
export(get_single_sample_records_by_medium)
export(get_single_sample_records_by_medium_batch)
export(get_skin_eye_hazard)
export(get_skin_eye_hazard_batch)
export(get_smiles)
export(has_ctxR_option)
export(has_ctxR_options)
export(has_ctx_key)
export(register_ctx_api_key)
export(set_ctxR_option)
export(showing_key)
import(data.table)
